MINISTER-PRESIDENT
##################

Geachte Minister-President,

Ik ben Bart Thate, een 50 jaar oude schizofrenie patient.

Op 20 Oktober 2012 heb ik na correspondentie met de Koningin een klacht tegen de Nederland ingedient (Thate tegen Nederland 69389/12). De klacht betrof het falen van de
(F)ACT methodiek, de methode die GGZ Nederland gebruikt om vorm te geven aan de wetten die gedwongen behandeling in Nederland mogelijk maken. De uitspraak is niet-ontvankelijk.

Omdat de Koningin gemeld heeft dat ze vanwege ministeriele verantwoordelijkheden geen tussenkomst kan bieden, wend ik mij tot u.

Er is bewijs dat antipsychotica schadelijk voor de hersenen zijn, bijv. Haldol brengt 4% aantasting van de hippocampus:

1) http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/ 
2) https://jamanetwork.com/journals/jamapsychiatry/article-abstract/2672208

De geneesmiddelenwet zegt dat u stoffen van de geneesmiddelenmarkt dient te halen als deze schadelijk blijken te zijn.
Daarom eis ik van u dat u direct medicijnen die gifstoffen blijken te zijn van de geneesmiddelmarkt haalt.

Er is bewijs dat antipsychotica gif zijn:

1) haloperiodol (haldol) - https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
2) clozapine (leponex) - https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831
3) olanzapine (zyprexa) - https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320
4) aripriprazole (abilify) https://echa.europa.eu/substance-information/-/substanceinfo/100.112.532

Dat het hier gif betreft en niet een onschadelijk medicijn maakt dat men een strafbaar feit pleegt. 
Daarom eis ik van u dat u gif toedieningen laat vervolgen door het Openbaar Ministerie.

Het is voor mij niet mogelijk gebleken om aangifte te doen van mishandeling als de psychiater zijn patient met gif mishandelt:

1) De IGZ treft geen structurele onzorgvuldigheid in de afhandeling van klachten bij GGZ-NHN aan.
2) De Hoge Raad concludeert dat het geen verantwoordelijkheid heeft en verwijst naar het Openbaar Ministerie, dat niet reageert.
3) Daarna heb ik het Europeese Hof voor de Rechten van de Mens aangeschreven om een klacht tegen Nederland in te dienen.
4) Pas na een gang langs het EVRM reageert Het Openbaar Ministerie wel en verwijst naar de IGZ, die de klacht melding al heeft afgesloten.

Het ontbreekt de GGZ patient aan een daadwerkelijke remedie om een einde te kunnen maken aan de mishandeling die een arts pleegt als hij gif toedient.
Daarom eis ik ook dat u voor de GGZ patient gif toedienende artsen laat vervolgen.

Mijn eisen zijn dus:

1) medicijnen die gif blijken te zijn van de markt af.
2) gif toedieningen door het Openbaar Ministerie laten vervolgen.
3) voor de GGZ patient deze vervolging te doen..
4) de casemanager in de Zorgverzekeringswet.

Er van uitgaande dat u mijn eisen inwilligt,



Bart Thate
